#!/usr/bin/ruby

###
### test the get_bugs interface, which returns the bugs matching the key-id pair from the BTS.
###

require 'aptlistbugs/debian/bts'
require 'aptlistbugs/debian/btssoap'
$DEBUG=1
soap=Debian::BTSSOAP::Soap.new
sa = Debian::BTSSOAP::StringArray.new
p soap.get_bugs('package','mercury','severity', 'serious');

